local player = {}
player.__index = player

local function new()
  return setmetatable({}, player)
end

function player:init(x, y, up, down, left, right)

	self.x = x
	self.y = y

	-- Player Attributes
	self.speed = 80
	self.dir = "down"

	self.dead = false
	self.health = 100

	-- Player Key Definitions
	self.upKey = up
	self.downKey = down
	self.leftKey = left
	self.rightKey = right

	-- Player Animation Shi7
	self.img = love.graphics.newImage("assets/male.png")
	self.grid = anim8.newGrid(32,32, 96, 128)
	
	self.moveUp = anim8.newAnimation('loop', self.grid('1-3,4'), 0.1)
	self.moveDown = anim8.newAnimation('loop', self.grid('1-3,1'), 0.1)
	self.moveLeft = anim8.newAnimation('loop', self.grid('1-3,2'), 0.1)
	self.moveRight = anim8.newAnimation('loop', self.grid('1-3,3'), 0.1)

end

function player:update(dt)
	
	-- Controls
	if love.keyboard.isDown(self.upKey) then
		self:move(dt, "up")
	end

	if love.keyboard.isDown(self.downKey) then
		self:move(dt, "down")
	end

	if love.keyboard.isDown(self.leftKey) then
		self:move(dt, "left")
	end

	if love.keyboard.isDown(self.rightKey) then
		self:move(dt, "right")
	end

end

function player:draw()

	if self.dir == "up" then
		self.moveUp:draw(self.img, self.x, self.y)
	elseif self.dir == "down" then
		self.moveDown:draw(self.img, self.x, self.y)
	elseif self.dir == "left" then
		self.moveLeft:draw(self.img, self.x, self.y)
	elseif self.dir == "right" then
		self.moveRight:draw(self.img, self.x, self.y)
	end

end

function player:move(dt, dir)
	self.dir = dir

	if dir == "up" then
		self.moveUp:update(dt)
	end

	if dir == "down" then
		self.moveDown:update(dt)
	end

	if dir == "left" then
		self.moveLeft:update(dt)
	end

	if dir == "right" then
		self.moveRight:update(dt)
	end

end

return setmetatable({new = new},
  {__call = function(_, ...) return new(...) end})
